@@ -59,10 +59,10 @@ PipeOpCollapseFactors = R6Class("PipeOpCollapseFactors",
   inherit = PipeOpTaskPreprocSimple,
   public = list(
     initialize = function(id = "collapsefactors", param_vals = list()) {
-      ps = ParamSet$new(params = list(
-        ParamDbl$new("no_collapse_above_prevalence", 0, 1, tags = c("train", "predict")),
-        ParamInt$new("target_level_count", 2, tags = c("train", "predict"))
-      ))
+      ps = ps(
+        no_collapse_above_prevalence = p_dbl(0, 1, tags = c("train", "predict")),
+        target_level_count = p_int(2, tags = c("train", "predict"))
+      )
       ps$values = list(no_collapse_above_prevalence = 1, target_level_count = 2)
       super$initialize(id, param_set = ps, param_vals = param_vals, feature_types = c("factor", "ordered"))
     }
